summaryrefslogtreecommitdiffstats
path: root/mobile/android/android-components/components/feature/prompts/src/main
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-12 05:35:29 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-12 05:35:29 +0000
commit59203c63bb777a3bacec32fb8830fba33540e809 (patch)
tree58298e711c0ff0575818c30485b44a2f21bf28a0 /mobile/android/android-components/components/feature/prompts/src/main
parentAdding upstream version 126.0.1. (diff)
downloadfirefox-59203c63bb777a3bacec32fb8830fba33540e809.tar.xz
firefox-59203c63bb777a3bacec32fb8830fba33540e809.zip
Adding upstream version 127.0.upstream/127.0
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'mobile/android/android-components/components/feature/prompts/src/main')
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/PromptFeature.kt37
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/dialog/TextPromptDialogFragment.kt13
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/res/values-br/strings.xml76
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/res/values-kab/strings.xml2
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/res/values-nn-rNO/strings.xml13
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/res/values-sc/strings.xml68
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/res/values-sl/strings.xml68
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/res/values-su/strings.xml70
-rw-r--r--mobile/android/android-components/components/feature/prompts/src/main/res/values/quarantined_strings.xml2
9 files changed, 226 insertions, 123 deletions
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/dialog/TextPromptDialogFragment.kt b/mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/dialog/TextPromptDialogFragment.kt
index 01492e96e4..41aeca796c 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/dialog/TextPromptDialogFragment.kt
+++ b/mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/dialog/TextPromptDialogFragment.kt
@@ -11,15 +11,18 @@ import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.LayoutInflater
+import android.view.inputmethod.EditorInfo.IME_NULL
import android.widget.EditText
import android.widget.TextView
import androidx.appcompat.app.AlertDialog
+import androidx.core.view.inputmethod.EditorInfoCompat.IME_FLAG_NO_PERSONALIZED_LEARNING
import mozilla.components.feature.prompts.R
import mozilla.components.ui.widgets.withCenterAlignedButtons
private const val KEY_USER_EDIT_TEXT = "KEY_USER_EDIT_TEXT"
private const val KEY_LABEL_INPUT = "KEY_LABEL_INPUT"
private const val KEY_DEFAULT_INPUT_VALUE = "KEY_DEFAULT_INPUT_VALUE"
+private const val KEY_PRIVATE = "KEY_PRIVATE"
/**
* [androidx.fragment.app.DialogFragment] implementation to display a
@@ -38,6 +41,11 @@ internal class TextPromptDialogFragment : AbstractPromptTextDialogFragment(), Te
*/
internal val labelInput: String? by lazy { safeArguments.getString(KEY_LABEL_INPUT) }
+ /**
+ * Tells if the Dialog is shown from private browsing
+ */
+ internal val private: Boolean? by lazy { safeArguments.getBoolean(KEY_PRIVATE) }
+
private var userSelectionEditText: String
get() = safeArguments.getString(KEY_USER_EDIT_TEXT, defaultInputValue)
set(value) {
@@ -73,6 +81,7 @@ internal class TextPromptDialogFragment : AbstractPromptTextDialogFragment(), Te
label.text = labelInput
editText.setText(defaultInputValue)
editText.addTextChangedListener(this)
+ editText.imeOptions = if (private == true) IME_FLAG_NO_PERSONALIZED_LEARNING else IME_NULL
addCheckBoxIfNeeded(view)
@@ -100,7 +109,9 @@ internal class TextPromptDialogFragment : AbstractPromptTextDialogFragment(), Te
* @param hasShownManyDialogs tells if this [sessionId] has shown many dialogs
* in a short period of time, if is true a checkbox will be part of the dialog, for the user
* to choose if wants to prevent this [sessionId] continuing showing dialogs.
+ * @param private tells if this dialog is triggered from private browsing
*/
+ @Suppress("complexity:LongParameterList")
fun newInstance(
sessionId: String,
promptRequestUID: String,
@@ -109,6 +120,7 @@ internal class TextPromptDialogFragment : AbstractPromptTextDialogFragment(), Te
inputLabel: String,
defaultInputValue: String,
hasShownManyDialogs: Boolean,
+ private: Boolean,
): TextPromptDialogFragment {
val fragment = TextPromptDialogFragment()
val arguments = fragment.arguments ?: Bundle()
@@ -121,6 +133,7 @@ internal class TextPromptDialogFragment : AbstractPromptTextDialogFragment(), Te
putString(KEY_LABEL_INPUT, inputLabel)
putString(KEY_DEFAULT_INPUT_VALUE, defaultInputValue)
putBoolean(KEY_MANY_ALERTS, hasShownManyDialogs)
+ putBoolean(KEY_PRIVATE, private)
}
fragment.arguments = arguments
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/res/values-br/strings.xml b/mobile/android/android-components/components/feature/prompts/src/main/res/values-br/strings.xml
index ee06036029..f7833ace0f 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/res/values-br/strings.xml
+++ b/mobile/android/android-components/components/feature/prompts/src/main/res/values-br/strings.xml
@@ -17,9 +17,9 @@
<!-- Text for password field in an authentication dialog. -->
<string name="mozac_feature_prompt_password_hint">Ger-tremen</string>
<!-- Negative confirmation that we should not save the new or updated login -->
- <string name="mozac_feature_prompt_dont_save">Na enrollañ</string>
+ <string name="mozac_feature_prompt_dont_save" moz:removedIn="125" tools:ignore="UnusedResources">Na enrollañ</string>
<!-- Negative confirmation that we should not save the new or updated login -->
- <string name="mozac_feature_prompt_dont_save_2" tools:ignore="UnusedResources">Diwezhatoc’h</string>
+ <string name="mozac_feature_prompt_dont_save_2">Diwezhatoc’h</string>
<!-- Negative confirmation that we should never save a login for this site -->
<string name="mozac_feature_prompt_never_save">Na enrollañ biken</string>
<!-- Negative confirmation that we should not save a credit card for this site -->
@@ -27,27 +27,27 @@
<!-- Positive confirmation that we should save the new or updated login -->
<string name="mozac_feature_prompt_save_confirmation">Enrollañ</string>
<!-- Negative confirmation that we should not save the updated login -->
- <string name="mozac_feature_prompt_dont_update">Na hizivaat</string>
+ <string name="mozac_feature_prompt_dont_update" moz:removedIn="125" tools:ignore="UnusedResources">Na hizivaat</string>
<!-- Negative confirmation that we should not save the updated login -->
- <string name="mozac_feature_prompt_dont_update_2" tools:ignore="UnusedResources">Diwezhatoc’h</string>
+ <string name="mozac_feature_prompt_dont_update_2">Diwezhatoc’h</string>
<!-- Positive confirmation that we should save the updated login -->
<string name="mozac_feature_prompt_update_confirmation">Hizivaat</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_empty_password">Ar vaezienn ger-tremen a rank bezañ leuniet</string>
+ <string name="mozac_feature_prompt_error_empty_password" moz:removedIn="125" tools:ignore="UnusedResources">Ar vaezienn ger-tremen a rank bezañ leuniet</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_empty_password_2" tools:ignore="UnusedResources">Enankit ur ger-tremen</string>
+ <string name="mozac_feature_prompt_error_empty_password_2">Enankit ur ger-tremen</string>
<!-- Error text displayed underneath the login field when it is in an error case -->
- <string name="mozac_feature_prompt_error_unknown_cause">Ne cʼhaller ket enrollañ an titour kennaskañ</string>
+ <string name="mozac_feature_prompt_error_unknown_cause" moz:removedIn="125" tools:ignore="UnusedResources">Ne cʼhaller ket enrollañ an titour kennaskañ</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_unknown_cause_2" tools:ignore="UnusedResources">N’haller ket enrollañ ar ger-tremen</string>
+ <string name="mozac_feature_prompt_error_unknown_cause_2">N’haller ket enrollañ ar ger-tremen</string>
<!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new login. -->
- <string name="mozac_feature_prompt_login_save_headline">Enrollañ an titour kennaskañ-mañ?</string>
+ <string name="mozac_feature_prompt_login_save_headline" moz:removedIn="125" tools:ignore="UnusedResources">Enrollañ an titour kennaskañ-mañ?</string>
<!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new password. -->
- <string name="mozac_feature_prompt_login_save_headline_2" tools:ignore="UnusedResources">Enrollañ ar ger-tremen?</string>
+ <string name="mozac_feature_prompt_login_save_headline_2">Enrollañ ar ger-tremen?</string>
<!-- Prompt message displayed when app detects a user has entered a new password for an existing login and user decides if app should update the login. -->
- <string name="mozac_feature_prompt_login_update_headline">Hizivaat an titour kennaskañ-mañ?</string>
+ <string name="mozac_feature_prompt_login_update_headline" moz:removedIn="125" tools:ignore="UnusedResources">Hizivaat an titour kennaskañ-mañ?</string>
<!-- Prompt message displayed when app detects a user has entered a new password for an existing login and user decides if app should update the password. -->
- <string name="mozac_feature_prompt_login_update_headline_2" tools:ignore="UnusedResources">Hizivaat ar ger-tremen?</string>
+ <string name="mozac_feature_prompt_login_update_headline_2">Hizivaat ar ger-tremen?</string>
<!-- Prompt message displayed when app detects a user has entered a username for an existing login without a username and user decides if app should update the login. -->
<string name="mozac_feature_prompt_login_add_username_headline">Ouzhpennañ an anv arveriad dʼar gerioù-tremen enrollet?</string>
<!-- Text for a label for the field when prompt requesting a text is shown. -->
@@ -96,22 +96,29 @@
<!-- Title of the time picker dialog. -->
<string name="mozac_feature_prompts_set_time">Dibab an eur</string>
<!-- Option in expanded select login prompt that links to login settings -->
- <string name="mozac_feature_prompts_manage_logins">Ardoer titouroù kennaskañ</string>
+ <string name="mozac_feature_prompts_manage_logins" moz:removedIn="125" tools:ignore="UnusedResources">Ardoer titouroù kennaskañ</string>
<!-- Option in expanded select password prompt that links to password settings -->
- <string name="mozac_feature_prompts_manage_logins_2" tools:ignore="UnusedResources">Merañ ar gerioù-tremen</string>
+ <string name="mozac_feature_prompts_manage_logins_2">Merañ ar gerioù-tremen</string>
<!-- Content description for expanding the saved logins options in the select login prompt -->
- <string name="mozac_feature_prompts_expand_logins_content_description">Brasaat an titouroù kennaskañ aliet</string>
+ <string name="mozac_feature_prompts_expand_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Brasaat an titouroù kennaskañ aliet</string>
<!-- Content description for expanding the saved passwords options in the select password prompt -->
- <string name="mozac_feature_prompts_expand_logins_content_description_2" tools:ignore="UnusedResources">Dispakañ ar gerioù-tremen enrollet</string>
+ <string name="mozac_feature_prompts_expand_logins_content_description_2">Dispakañ ar gerioù-tremen enrollet</string>
<!-- Content description for collapsing the saved logins options in the select login prompt -->
- <string name="mozac_feature_prompts_collapse_logins_content_description">Berraat an titouroù kennaskañ aliet</string>
+ <string name="mozac_feature_prompts_collapse_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Berraat an titouroù kennaskañ aliet</string>
<!-- Content description for collapsing the saved passwords options in the select password prompt -->
- <string name="mozac_feature_prompts_collapse_logins_content_description_2" tools:ignore="UnusedResources">Kuzhat ar gerioù-tremen enrollet</string>
+ <string name="mozac_feature_prompts_collapse_logins_content_description_2">Kuzhat ar gerioù-tremen enrollet</string>
<!-- Header for the select login prompt to allow users to fill a form with a saved login -->
- <string name="mozac_feature_prompts_saved_logins">Titouroù kennaskañ aliet</string>
+ <string name="mozac_feature_prompts_saved_logins" moz:removedIn="125" tools:ignore="UnusedResources">Titouroù kennaskañ aliet</string>
<!-- Header for the select password prompt to allow users to fill a form with a saved password -->
- <string name="mozac_feature_prompts_saved_logins_2" tools:ignore="UnusedResources">Gerioù-tremen enrollet</string>
+ <string name="mozac_feature_prompts_saved_logins_2">Gerioù-tremen enrollet</string>
+
+ <!-- Content description for the suggest strong password prompt to allow users to fill a form with a suggested strong password -->
+ <string name="mozac_feature_prompts_suggest_strong_password_content_description">Kinnig ur ger-tremen kreñv</string>
+ <!-- Header for the suggest strong password prompt to allow users to fill a form with a suggested strong password -->
+ <string name="mozac_feature_prompts_suggest_strong_password">Kinnig ur ger-tremen kreñv</string>
+ <!-- Title for using the suggest strong password confirmation dialog. %1$s will be replaced with the generated password -->
+ <string name="mozac_feature_prompts_suggest_strong_password_message">Implij ur ger-tremen kreñv: %1$s</string>
<!-- Strings shown in a dialog that appear when users try to refresh a certain kind of webpages -->
<string name="mozac_feature_prompt_repost_title">Kas roadennoù en-dro d’al lec’hienn?</string>
@@ -123,38 +130,43 @@
<!-- Credit Card Autofill -->
<!-- Header for the select credit card prompt to allow users to fill a form with a saved credit card. -->
- <string name="mozac_feature_prompts_select_credit_card">Diuzañ ur gartenn gred</string>
+ <string name="mozac_feature_prompts_select_credit_card" moz:removedIn="125" tools:ignore="UnusedResources">Diuzañ ur gartenn gred</string>
+ <!-- Header for the select card prompt to allow users to fill a form with a saved card. -->
+ <string name="mozac_feature_prompts_select_credit_card_2">Ober gant ur gartenn enrollet</string>
<!-- Content description for expanding the select credit card options in the select credit card prompt. -->
- <string name="mozac_feature_prompts_expand_credit_cards_content_description">Astenn ar cʼhartennoù kred kinniget</string>
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Astenn ar cʼhartennoù kred kinniget</string>
<!-- Content description for expanding the saved card options in the select card prompt. -->
- <string name="mozac_feature_prompts_expand_credit_cards_content_description_2" tools:ignore="UnusedResources">Dispakañ ar c’hartennoù enrollet</string>
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description_2">Dispakañ ar c’hartennoù enrollet</string>
<!-- Content description for collapsing the select credit card options in the select credit prompt. -->
- <string name="mozac_feature_prompts_collapse_credit_cards_content_description">Bihanaat ar cʼhartennoù kred kinniget</string>
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Bihanaat ar cʼhartennoù kred kinniget</string>
<!-- Content description for collapsing the saved card options in the select prompt. -->
- <string name="mozac_feature_prompts_collapse_credit_cards_content_description_2" tools:ignore="UnusedResources">Kuzhat ar c’hartennoù enrollet</string>
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description_2">Kuzhat ar c’hartennoù enrollet</string>
<!-- Option in the expanded select credit card prompt that links to credit cards settings. -->
- <string name="mozac_feature_prompts_manage_credit_cards">Merañ ar cʼhartennoù kred</string>
+ <string name="mozac_feature_prompts_manage_credit_cards" moz:removedIn="125" tools:ignore="UnusedResources">Merañ ar cʼhartennoù kred</string>
<!-- Option in the expanded select card prompt that links to cards settings. -->
- <string name="mozac_feature_prompts_manage_credit_cards_2" tools:ignore="UnusedResources">Merañ ar c’hartennoù</string>
+ <string name="mozac_feature_prompts_manage_credit_cards_2">Merañ ar c’hartennoù</string>
<!-- Text for the title of a save credit card dialog. -->
<string name="mozac_feature_prompts_save_credit_card_prompt_title">Enrollañ ar gartenn-mañ en surentez?</string>
<!-- Text for the title of an update credit card dialog. -->
<string name="mozac_feature_prompts_update_credit_card_prompt_title">Hizivaat deiziad termen ar gartenn?</string>
<!-- Subtitle text displayed under the title of the save credit card dialog. -->
- <string name="mozac_feature_prompts_save_credit_card_prompt_body">Enrigenet e vo niverenn ar gartenn. Ne vo ket enrollet ar c’hod surentez.</string>
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body" moz:removedIn="125" tools:ignore="UnusedResources">Enrigenet e vo niverenn ar gartenn. Ne vo ket enrollet ar c’hod surentez.</string>
+
+ <!-- Subtitle text displayed under the title of the saved card dialog. Parameter will be replaced by app name-->
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body_2">%s a enrinego ho niverenn gartenn. Ne vo ket enrollet ho poneg surentez.</string>
<!-- Address Autofill -->
<!-- Header for the select address prompt to allow users to fill a form with a saved address. -->
<string name="mozac_feature_prompts_select_address_2">Dibab ur chomlec’h</string>
<!-- Content description for expanding the select addresses options in the select address prompt. -->
- <string name="mozac_feature_prompts_expand_address_content_description">Displegañ ar chomlec’hioù kinniget</string>
+ <string name="mozac_feature_prompts_expand_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Displegañ ar chomlec’hioù kinniget</string>
<!-- Content description for expanding the saved addresses options in the select address prompt. -->
- <string name="mozac_feature_prompts_expand_address_content_description_2" tools:ignore="UnusedResources">Dispakañ ar chomlec’hioù enrollet</string>
+ <string name="mozac_feature_prompts_expand_address_content_description_2">Dispakañ ar chomlec’hioù enrollet</string>
<!-- Content description for collapsing the select address options in the select address prompt. -->
- <string name="mozac_feature_prompts_collapse_address_content_description">Plegañ ar chomlec’hioù kinniget</string>
+ <string name="mozac_feature_prompts_collapse_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Plegañ ar chomlec’hioù kinniget</string>
<!-- Content description for collapsing the saved address options in the select address prompt. -->
- <string name="mozac_feature_prompts_collapse_address_content_description_2" tools:ignore="UnusedResources">Kuzhat ar chomlec’hioù enrollet</string>
+ <string name="mozac_feature_prompts_collapse_address_content_description_2">Kuzhat ar chomlec’hioù enrollet</string>
<!-- Text for the manage addresses button. -->
<string name="mozac_feature_prompts_manage_address">Merañ ar chomlec’hioù</string>
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/res/values-kab/strings.xml b/mobile/android/android-components/components/feature/prompts/src/main/res/values-kab/strings.xml
index dc9067b13a..595f0075a4 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/res/values-kab/strings.xml
+++ b/mobile/android/android-components/components/feature/prompts/src/main/res/values-kab/strings.xml
@@ -103,6 +103,8 @@
<string name="mozac_feature_prompts_expand_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Sken-d inekcam isumar</string>
<!-- Content description for collapsing the saved logins options in the select login prompt -->
<string name="mozac_feature_prompts_collapse_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Ffer inekcam isumar</string>
+ <!-- Content description for collapsing the saved passwords options in the select password prompt -->
+ <string name="mozac_feature_prompts_collapse_logins_content_description_2">Fneḍ awalen n uεeddi i yettwaskelsen</string>
<!-- Header for the select login prompt to allow users to fill a form with a saved login -->
<string name="mozac_feature_prompts_saved_logins" moz:removedIn="125" tools:ignore="UnusedResources">Inekcam yettwasumren</string>
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/res/values-nn-rNO/strings.xml b/mobile/android/android-components/components/feature/prompts/src/main/res/values-nn-rNO/strings.xml
index 6266243205..15d975b4eb 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/res/values-nn-rNO/strings.xml
+++ b/mobile/android/android-components/components/feature/prompts/src/main/res/values-nn-rNO/strings.xml
@@ -38,6 +38,8 @@
<string name="mozac_feature_prompt_error_empty_password_2">Skriv inn passord</string>
<!-- Error text displayed underneath the login field when it is in an error case -->
<string name="mozac_feature_prompt_error_unknown_cause" moz:removedIn="125" tools:ignore="UnusedResources">Klarte ikkje å lagre innlogginga</string>
+ <!-- Error text displayed underneath the password field when it is in an error case -->
+ <string name="mozac_feature_prompt_error_unknown_cause_2">Kan ikkje lagre passordet</string>
<!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new login. -->
<string name="mozac_feature_prompt_login_save_headline" moz:removedIn="125" tools:ignore="UnusedResources">Lagre denne innlogginga?</string>
<!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new password. -->
@@ -103,6 +105,8 @@
<string name="mozac_feature_prompts_expand_logins_content_description_2">Utvid lagra passord</string>
<!-- Content description for collapsing the saved logins options in the select login prompt -->
<string name="mozac_feature_prompts_collapse_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Slå saman føreslåtte innloggingar</string>
+ <!-- Content description for collapsing the saved passwords options in the select password prompt -->
+ <string name="mozac_feature_prompts_collapse_logins_content_description_2">Skjul lagra passord</string>
<!-- Header for the select login prompt to allow users to fill a form with a saved login -->
<string name="mozac_feature_prompts_saved_logins" moz:removedIn="125" tools:ignore="UnusedResources">Føreslåtte innloggingar</string>
@@ -131,8 +135,12 @@
<string name="mozac_feature_prompts_select_credit_card_2">Bruk lagra kort</string>
<!-- Content description for expanding the select credit card options in the select credit card prompt. -->
<string name="mozac_feature_prompts_expand_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Utvid føreslått betalingskort</string>
+ <!-- Content description for expanding the saved card options in the select card prompt. -->
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description_2">Utvid lagra passord</string>
<!-- Content description for collapsing the select credit card options in the select credit prompt. -->
<string name="mozac_feature_prompts_collapse_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Minimer føreslått betalingskort</string>
+ <!-- Content description for collapsing the saved card options in the select prompt. -->
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description_2">Skjul lagra kort</string>
<!-- Option in the expanded select credit card prompt that links to credit cards settings. -->
<string name="mozac_feature_prompts_manage_credit_cards" moz:removedIn="125" tools:ignore="UnusedResources">Handsam betalingskort</string>
<!-- Option in the expanded select card prompt that links to cards settings. -->
@@ -144,6 +152,9 @@
<!-- Subtitle text displayed under the title of the save credit card dialog. -->
<string name="mozac_feature_prompts_save_credit_card_prompt_body" moz:removedIn="125" tools:ignore="UnusedResources">Kortnummeret vil bli kryptert. Tryggingskoden vert ikkje lagra.</string>
+ <!-- Subtitle text displayed under the title of the saved card dialog. Parameter will be replaced by app name-->
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body_2">%s krypterer kortnummeret ditt. Sikkerheitskoden din vert ikkje lagra.</string>
+
<!-- Address Autofill -->
<!-- Header for the select address prompt to allow users to fill a form with a saved address. -->
<string name="mozac_feature_prompts_select_address_2">Vel adresse</string>
@@ -153,6 +164,8 @@
<string name="mozac_feature_prompts_expand_address_content_description_2">Utvid lagra adresser</string>
<!-- Content description for collapsing the select address options in the select address prompt. -->
<string name="mozac_feature_prompts_collapse_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Slå saman føreslåtte adresser</string>
+ <!-- Content description for collapsing the saved address options in the select address prompt. -->
+ <string name="mozac_feature_prompts_collapse_address_content_description_2">Skjul lagra adresser</string>
<!-- Text for the manage addresses button. -->
<string name="mozac_feature_prompts_manage_address">Handsam adresser</string>
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/res/values-sc/strings.xml b/mobile/android/android-components/components/feature/prompts/src/main/res/values-sc/strings.xml
index e4dd91d8c6..74d17b4a10 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/res/values-sc/strings.xml
+++ b/mobile/android/android-components/components/feature/prompts/src/main/res/values-sc/strings.xml
@@ -17,9 +17,9 @@
<!-- Text for password field in an authentication dialog. -->
<string name="mozac_feature_prompt_password_hint">Crae</string>
<!-- Negative confirmation that we should not save the new or updated login -->
- <string name="mozac_feature_prompt_dont_save">Non sarves</string>
+ <string name="mozac_feature_prompt_dont_save" moz:removedIn="125" tools:ignore="UnusedResources">Non sarves</string>
<!-- Negative confirmation that we should not save the new or updated login -->
- <string name="mozac_feature_prompt_dont_save_2" tools:ignore="UnusedResources">Immoe nono</string>
+ <string name="mozac_feature_prompt_dont_save_2">Immoe nono</string>
<!-- Negative confirmation that we should never save a login for this site -->
<string name="mozac_feature_prompt_never_save">Non sarves mai</string>
<!-- Negative confirmation that we should not save a credit card for this site -->
@@ -27,27 +27,27 @@
<!-- Positive confirmation that we should save the new or updated login -->
<string name="mozac_feature_prompt_save_confirmation">Sarva</string>
<!-- Negative confirmation that we should not save the updated login -->
- <string name="mozac_feature_prompt_dont_update">No atualizes</string>
+ <string name="mozac_feature_prompt_dont_update" moz:removedIn="125" tools:ignore="UnusedResources">No atualizes</string>
<!-- Negative confirmation that we should not save the updated login -->
- <string name="mozac_feature_prompt_dont_update_2" tools:ignore="UnusedResources">Immoe nono</string>
+ <string name="mozac_feature_prompt_dont_update_2">Immoe nono</string>
<!-- Positive confirmation that we should save the updated login -->
<string name="mozac_feature_prompt_update_confirmation">Atualiza</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_empty_password">Sa crae non podet èssere bòida</string>
+ <string name="mozac_feature_prompt_error_empty_password" moz:removedIn="125" tools:ignore="UnusedResources">Sa crae non podet èssere bòida</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_empty_password_2" tools:ignore="UnusedResources">Inserta una crae</string>
+ <string name="mozac_feature_prompt_error_empty_password_2">Inserta una crae</string>
<!-- Error text displayed underneath the login field when it is in an error case -->
- <string name="mozac_feature_prompt_error_unknown_cause">Impossìbile sarvare is credentziales</string>
+ <string name="mozac_feature_prompt_error_unknown_cause" moz:removedIn="125" tools:ignore="UnusedResources">Impossìbile sarvare is credentziales</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_unknown_cause_2" tools:ignore="UnusedResources">Impossìbile sarvare sa crae</string>
+ <string name="mozac_feature_prompt_error_unknown_cause_2">Impossìbile sarvare sa crae</string>
<!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new login. -->
- <string name="mozac_feature_prompt_login_save_headline">Boles sarvare custa credentziale?</string>
+ <string name="mozac_feature_prompt_login_save_headline" moz:removedIn="125" tools:ignore="UnusedResources">Boles sarvare custa credentziale?</string>
<!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new password. -->
- <string name="mozac_feature_prompt_login_save_headline_2" tools:ignore="UnusedResources">Boles sarvare sa crae?</string>
+ <string name="mozac_feature_prompt_login_save_headline_2">Boles sarvare sa crae?</string>
<!-- Prompt message displayed when app detects a user has entered a new password for an existing login and user decides if app should update the login. -->
- <string name="mozac_feature_prompt_login_update_headline">Boles atualizare custa credentziale?</string>
+ <string name="mozac_feature_prompt_login_update_headline" moz:removedIn="125" tools:ignore="UnusedResources">Boles atualizare custa credentziale?</string>
<!-- Prompt message displayed when app detects a user has entered a new password for an existing login and user decides if app should update the password. -->
- <string name="mozac_feature_prompt_login_update_headline_2" tools:ignore="UnusedResources">Boles atualizare sa crae?</string>
+ <string name="mozac_feature_prompt_login_update_headline_2">Boles atualizare sa crae?</string>
<!-- Prompt message displayed when app detects a user has entered a username for an existing login without a username and user decides if app should update the login. -->
<string name="mozac_feature_prompt_login_add_username_headline">Boles agiùnghere su nòmine de utente a sa crae sarvada?</string>
<!-- Text for a label for the field when prompt requesting a text is shown. -->
@@ -97,18 +97,22 @@
<!-- Title of the time picker dialog. -->
<string name="mozac_feature_prompts_set_time">Cunfigura s’ora</string>
<!-- Option in expanded select login prompt that links to login settings -->
- <string name="mozac_feature_prompts_manage_logins">Gesti is credentziales</string>
+ <string name="mozac_feature_prompts_manage_logins" moz:removedIn="125" tools:ignore="UnusedResources">Gesti is credentziales</string>
<!-- Option in expanded select password prompt that links to password settings -->
- <string name="mozac_feature_prompts_manage_logins_2" tools:ignore="UnusedResources">Gesti is craes</string>
+ <string name="mozac_feature_prompts_manage_logins_2">Gesti is craes</string>
<!-- Content description for expanding the saved logins options in the select login prompt -->
- <string name="mozac_feature_prompts_expand_logins_content_description">Ismànnia is credentziales cussigiadas</string>
+ <string name="mozac_feature_prompts_expand_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Ismànnia is credentziales cussigiadas</string>
+ <!-- Content description for expanding the saved passwords options in the select password prompt -->
+ <string name="mozac_feature_prompts_expand_logins_content_description_2">Ismànnia is craes sarvadas</string>
<!-- Content description for collapsing the saved logins options in the select login prompt -->
- <string name="mozac_feature_prompts_collapse_logins_content_description">Mìnima is credentziales cussigiadas</string>
+ <string name="mozac_feature_prompts_collapse_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Mìnima is credentziales cussigiadas</string>
+ <!-- Content description for collapsing the saved passwords options in the select password prompt -->
+ <string name="mozac_feature_prompts_collapse_logins_content_description_2">Mìnima is craes sarvadas</string>
<!-- Header for the select login prompt to allow users to fill a form with a saved login -->
- <string name="mozac_feature_prompts_saved_logins">Credentziales cussigiadas</string>
+ <string name="mozac_feature_prompts_saved_logins" moz:removedIn="125" tools:ignore="UnusedResources">Credentziales cussigiadas</string>
<!-- Header for the select password prompt to allow users to fill a form with a saved password -->
- <string name="mozac_feature_prompts_saved_logins_2" tools:ignore="UnusedResources">Craes sarvadas</string>
+ <string name="mozac_feature_prompts_saved_logins_2">Craes sarvadas</string>
<!-- Content description for the suggest strong password prompt to allow users to fill a form with a suggested strong password -->
<string name="mozac_feature_prompts_suggest_strong_password_content_description">Cussìgia una crae segura</string>
@@ -126,35 +130,43 @@
<!-- Credit Card Autofill -->
<!-- Header for the select credit card prompt to allow users to fill a form with a saved credit card. -->
- <string name="mozac_feature_prompts_select_credit_card">Seletziona una carta de crèditu</string>
+ <string name="mozac_feature_prompts_select_credit_card" moz:removedIn="125" tools:ignore="UnusedResources">Seletziona una carta de crèditu</string>
<!-- Header for the select card prompt to allow users to fill a form with a saved card. -->
- <string name="mozac_feature_prompts_select_credit_card_2" tools:ignore="UnusedResources">Imprea una carta sarvada</string>
+ <string name="mozac_feature_prompts_select_credit_card_2">Imprea una carta sarvada</string>
<!-- Content description for expanding the select credit card options in the select credit card prompt. -->
- <string name="mozac_feature_prompts_expand_credit_cards_content_description">Ismànnia is cartas de crèditu cussigiadas</string>
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Ismànnia is cartas de crèditu cussigiadas</string>
+ <!-- Content description for expanding the saved card options in the select card prompt. -->
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description_2">Ismànnia is cartas sarvadas</string>
<!-- Content description for collapsing the select credit card options in the select credit prompt. -->
- <string name="mozac_feature_prompts_collapse_credit_cards_content_description">Mìnima is cartas de crèditu cussigiadas</string>
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Mìnima is cartas de crèditu cussigiadas</string>
+ <!-- Content description for collapsing the saved card options in the select prompt. -->
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description_2">Mìnima is cartas sarvadas</string>
<!-- Option in the expanded select credit card prompt that links to credit cards settings. -->
- <string name="mozac_feature_prompts_manage_credit_cards">Gesti is cartas de crèditu</string>
+ <string name="mozac_feature_prompts_manage_credit_cards" moz:removedIn="125" tools:ignore="UnusedResources">Gesti is cartas de crèditu</string>
<!-- Option in the expanded select card prompt that links to cards settings. -->
- <string name="mozac_feature_prompts_manage_credit_cards_2" tools:ignore="UnusedResources">Gesti is cartas</string>
+ <string name="mozac_feature_prompts_manage_credit_cards_2">Gesti is cartas</string>
<!-- Text for the title of a save credit card dialog. -->
<string name="mozac_feature_prompts_save_credit_card_prompt_title">Boles sarvare custa carta cun seguresa?</string>
<!-- Text for the title of an update credit card dialog. -->
<string name="mozac_feature_prompts_update_credit_card_prompt_title">Boles atualizare sa data de iscadèntzia de sa carta?</string>
<!-- Subtitle text displayed under the title of the save credit card dialog. -->
- <string name="mozac_feature_prompts_save_credit_card_prompt_body">Su nùmeru de carta at a èssere tzifradu. Su còdighe de seguresa no at a èssere sarvadu.</string>
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body" moz:removedIn="125" tools:ignore="UnusedResources">Su nùmeru de carta at a èssere tzifradu. Su còdighe de seguresa no at a èssere sarvadu.</string>
<!-- Subtitle text displayed under the title of the saved card dialog. Parameter will be replaced by app name-->
- <string name="mozac_feature_prompts_save_credit_card_prompt_body_2" tools:ignore="UnusedResources">%s tzifrat su nùmeru de sa carta tua. Su còdighe de seguresa no at a èssere sarvadu.</string>
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body_2">%s tzifrat su nùmeru de sa carta tua. Su còdighe de seguresa no at a èssere sarvadu.</string>
<!-- Address Autofill -->
<!-- Header for the select address prompt to allow users to fill a form with a saved address. -->
<string name="mozac_feature_prompts_select_address_2">Seletziona un’indiritzu</string>
<!-- Content description for expanding the select addresses options in the select address prompt. -->
- <string name="mozac_feature_prompts_expand_address_content_description">Ismànnia is indiritzos cussigiados</string>
+ <string name="mozac_feature_prompts_expand_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Ismànnia is indiritzos cussigiados</string>
+ <!-- Content description for expanding the saved addresses options in the select address prompt. -->
+ <string name="mozac_feature_prompts_expand_address_content_description_2">Ismànnia is indiritzos sarvados</string>
<!-- Content description for collapsing the select address options in the select address prompt. -->
- <string name="mozac_feature_prompts_collapse_address_content_description">Mìnima is indiritzos cussigiados</string>
+ <string name="mozac_feature_prompts_collapse_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Mìnima is indiritzos cussigiados</string>
+ <!-- Content description for collapsing the saved address options in the select address prompt. -->
+ <string name="mozac_feature_prompts_collapse_address_content_description_2">Mìnima is indiritzos sarvados</string>
<!-- Text for the manage addresses button. -->
<string name="mozac_feature_prompts_manage_address">Gesti is indiritzos</string>
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/res/values-sl/strings.xml b/mobile/android/android-components/components/feature/prompts/src/main/res/values-sl/strings.xml
index dec932c1c5..afe0f515ca 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/res/values-sl/strings.xml
+++ b/mobile/android/android-components/components/feature/prompts/src/main/res/values-sl/strings.xml
@@ -17,9 +17,9 @@
<!-- Text for password field in an authentication dialog. -->
<string name="mozac_feature_prompt_password_hint">Geslo</string>
<!-- Negative confirmation that we should not save the new or updated login -->
- <string name="mozac_feature_prompt_dont_save">Ne shrani</string>
+ <string name="mozac_feature_prompt_dont_save" moz:removedIn="125" tools:ignore="UnusedResources">Ne shrani</string>
<!-- Negative confirmation that we should not save the new or updated login -->
- <string name="mozac_feature_prompt_dont_save_2" tools:ignore="UnusedResources">Ne zdaj</string>
+ <string name="mozac_feature_prompt_dont_save_2">Ne zdaj</string>
<!-- Negative confirmation that we should never save a login for this site -->
<string name="mozac_feature_prompt_never_save">Nikoli ne shranjuj</string>
<!-- Negative confirmation that we should not save a credit card for this site -->
@@ -27,23 +27,27 @@
<!-- Positive confirmation that we should save the new or updated login -->
<string name="mozac_feature_prompt_save_confirmation">Shrani</string>
<!-- Negative confirmation that we should not save the updated login -->
- <string name="mozac_feature_prompt_dont_update">Ne posodobi</string>
+ <string name="mozac_feature_prompt_dont_update" moz:removedIn="125" tools:ignore="UnusedResources">Ne posodobi</string>
<!-- Negative confirmation that we should not save the updated login -->
- <string name="mozac_feature_prompt_dont_update_2" tools:ignore="UnusedResources">Ne zdaj</string>
+ <string name="mozac_feature_prompt_dont_update_2">Ne zdaj</string>
<!-- Positive confirmation that we should save the updated login -->
<string name="mozac_feature_prompt_update_confirmation">Posodobi</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_empty_password">Polje za geslo ne sme biti prazno</string>
+ <string name="mozac_feature_prompt_error_empty_password" moz:removedIn="125" tools:ignore="UnusedResources">Polje za geslo ne sme biti prazno</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_empty_password_2" tools:ignore="UnusedResources">Vnesite geslo</string>
+ <string name="mozac_feature_prompt_error_empty_password_2">Vnesite geslo</string>
<!-- Error text displayed underneath the login field when it is in an error case -->
- <string name="mozac_feature_prompt_error_unknown_cause">Ni mogoče shraniti povezave</string>
+ <string name="mozac_feature_prompt_error_unknown_cause" moz:removedIn="125" tools:ignore="UnusedResources">Ni mogoče shraniti povezave</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_unknown_cause_2" tools:ignore="UnusedResources">Gesla ni mogoče shraniti</string>
+ <string name="mozac_feature_prompt_error_unknown_cause_2">Gesla ni mogoče shraniti</string>
<!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new login. -->
- <string name="mozac_feature_prompt_login_save_headline">Shranim to prijavo?</string>
+ <string name="mozac_feature_prompt_login_save_headline" moz:removedIn="125" tools:ignore="UnusedResources">Shranim to prijavo?</string>
+ <!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new password. -->
+ <string name="mozac_feature_prompt_login_save_headline_2">Shranim geslo?</string>
<!-- Prompt message displayed when app detects a user has entered a new password for an existing login and user decides if app should update the login. -->
- <string name="mozac_feature_prompt_login_update_headline">Posodobim to prijavo?</string>
+ <string name="mozac_feature_prompt_login_update_headline" moz:removedIn="125" tools:ignore="UnusedResources">Posodobim to prijavo?</string>
+ <!-- Prompt message displayed when app detects a user has entered a new password for an existing login and user decides if app should update the password. -->
+ <string name="mozac_feature_prompt_login_update_headline_2">Posodobim geslo?</string>
<!-- Prompt message displayed when app detects a user has entered a username for an existing login without a username and user decides if app should update the login. -->
<string name="mozac_feature_prompt_login_add_username_headline">Dodaj shranjenemu geslu uporabniško ime?</string>
<!-- Text for a label for the field when prompt requesting a text is shown. -->
@@ -92,22 +96,22 @@
<!-- Title of the time picker dialog. -->
<string name="mozac_feature_prompts_set_time">Nastavi čas</string>
<!-- Option in expanded select login prompt that links to login settings -->
- <string name="mozac_feature_prompts_manage_logins">Upravljanje prijav</string>
+ <string name="mozac_feature_prompts_manage_logins" moz:removedIn="125" tools:ignore="UnusedResources">Upravljanje prijav</string>
<!-- Option in expanded select password prompt that links to password settings -->
- <string name="mozac_feature_prompts_manage_logins_2" tools:ignore="UnusedResources">Upravljanje gesel</string>
+ <string name="mozac_feature_prompts_manage_logins_2">Upravljanje gesel</string>
<!-- Content description for expanding the saved logins options in the select login prompt -->
- <string name="mozac_feature_prompts_expand_logins_content_description">Razširi predlagane prijave</string>
+ <string name="mozac_feature_prompts_expand_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Razširi predlagane prijave</string>
<!-- Content description for expanding the saved passwords options in the select password prompt -->
- <string name="mozac_feature_prompts_expand_logins_content_description_2" tools:ignore="UnusedResources">Prikaži shranjena gesla</string>
+ <string name="mozac_feature_prompts_expand_logins_content_description_2">Prikaži shranjena gesla</string>
<!-- Content description for collapsing the saved logins options in the select login prompt -->
- <string name="mozac_feature_prompts_collapse_logins_content_description">Strni predlagane prijave</string>
+ <string name="mozac_feature_prompts_collapse_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Strni predlagane prijave</string>
<!-- Content description for collapsing the saved passwords options in the select password prompt -->
- <string name="mozac_feature_prompts_collapse_logins_content_description_2" tools:ignore="UnusedResources">Skrij shranjena gesla</string>
+ <string name="mozac_feature_prompts_collapse_logins_content_description_2">Skrij shranjena gesla</string>
<!-- Header for the select login prompt to allow users to fill a form with a saved login -->
- <string name="mozac_feature_prompts_saved_logins">Predlagane prijave</string>
+ <string name="mozac_feature_prompts_saved_logins" moz:removedIn="125" tools:ignore="UnusedResources">Predlagane prijave</string>
<!-- Header for the select password prompt to allow users to fill a form with a saved password -->
- <string name="mozac_feature_prompts_saved_logins_2" tools:ignore="UnusedResources">Shranjena gesla</string>
+ <string name="mozac_feature_prompts_saved_logins_2">Shranjena gesla</string>
<!-- Content description for the suggest strong password prompt to allow users to fill a form with a suggested strong password -->
<string name="mozac_feature_prompts_suggest_strong_password_content_description">Predlagaj močno geslo</string>
@@ -126,42 +130,42 @@
<!-- Credit Card Autofill -->
<!-- Header for the select credit card prompt to allow users to fill a form with a saved credit card. -->
- <string name="mozac_feature_prompts_select_credit_card">Izberite kreditno kartico</string>
+ <string name="mozac_feature_prompts_select_credit_card" moz:removedIn="125" tools:ignore="UnusedResources">Izberite kreditno kartico</string>
<!-- Header for the select card prompt to allow users to fill a form with a saved card. -->
- <string name="mozac_feature_prompts_select_credit_card_2" tools:ignore="UnusedResources">Uporabi shranjeno kartico</string>
+ <string name="mozac_feature_prompts_select_credit_card_2">Uporabi shranjeno kartico</string>
<!-- Content description for expanding the select credit card options in the select credit card prompt. -->
- <string name="mozac_feature_prompts_expand_credit_cards_content_description">Razširi predlagane kreditne kartice</string>
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Razširi predlagane kreditne kartice</string>
<!-- Content description for expanding the saved card options in the select card prompt. -->
- <string name="mozac_feature_prompts_expand_credit_cards_content_description_2" tools:ignore="UnusedResources">Prikaži shranjene kartice</string>
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description_2">Prikaži shranjene kartice</string>
<!-- Content description for collapsing the select credit card options in the select credit prompt. -->
- <string name="mozac_feature_prompts_collapse_credit_cards_content_description">Strni predlagane kreditne kartice</string>
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Strni predlagane kreditne kartice</string>
<!-- Content description for collapsing the saved card options in the select prompt. -->
- <string name="mozac_feature_prompts_collapse_credit_cards_content_description_2" tools:ignore="UnusedResources">Skrij shranjene kartice</string>
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description_2">Skrij shranjene kartice</string>
<!-- Option in the expanded select credit card prompt that links to credit cards settings. -->
- <string name="mozac_feature_prompts_manage_credit_cards">Upravljanje kreditnih kartic</string>
+ <string name="mozac_feature_prompts_manage_credit_cards" moz:removedIn="125" tools:ignore="UnusedResources">Upravljanje kreditnih kartic</string>
<!-- Option in the expanded select card prompt that links to cards settings. -->
- <string name="mozac_feature_prompts_manage_credit_cards_2" tools:ignore="UnusedResources">Upravljanje kartic</string>
+ <string name="mozac_feature_prompts_manage_credit_cards_2">Upravljanje kartic</string>
<!-- Text for the title of a save credit card dialog. -->
<string name="mozac_feature_prompts_save_credit_card_prompt_title">Želite varno shraniti to kartico?</string>
<!-- Text for the title of an update credit card dialog. -->
<string name="mozac_feature_prompts_update_credit_card_prompt_title">Posodobi datum poteka veljavnosti kartice?</string>
<!-- Subtitle text displayed under the title of the save credit card dialog. -->
- <string name="mozac_feature_prompts_save_credit_card_prompt_body">Številka kartice bo šifrirana. Varnostna koda ne bo shranjena.</string>
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body" moz:removedIn="125" tools:ignore="UnusedResources">Številka kartice bo šifrirana. Varnostna koda ne bo shranjena.</string>
<!-- Subtitle text displayed under the title of the saved card dialog. Parameter will be replaced by app name-->
- <string name="mozac_feature_prompts_save_credit_card_prompt_body_2" tools:ignore="UnusedResources">%s šifrira številko vaše kartice. Varnostna koda se ne bo shranila.</string>
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body_2">%s šifrira številko vaše kartice. Varnostna koda se ne bo shranila.</string>
<!-- Address Autofill -->
<!-- Header for the select address prompt to allow users to fill a form with a saved address. -->
<string name="mozac_feature_prompts_select_address_2">Izbira naslova</string>
<!-- Content description for expanding the select addresses options in the select address prompt. -->
- <string name="mozac_feature_prompts_expand_address_content_description">Razširi predlagane naslove</string>
+ <string name="mozac_feature_prompts_expand_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Razširi predlagane naslove</string>
<!-- Content description for expanding the saved addresses options in the select address prompt. -->
- <string name="mozac_feature_prompts_expand_address_content_description_2" tools:ignore="UnusedResources">Prikaži shranjene naslove</string>
+ <string name="mozac_feature_prompts_expand_address_content_description_2">Prikaži shranjene naslove</string>
<!-- Content description for collapsing the select address options in the select address prompt. -->
- <string name="mozac_feature_prompts_collapse_address_content_description">Strni predlagane naslove</string>
+ <string name="mozac_feature_prompts_collapse_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Strni predlagane naslove</string>
<!-- Content description for collapsing the saved address options in the select address prompt. -->
- <string name="mozac_feature_prompts_collapse_address_content_description_2" tools:ignore="UnusedResources">Skrij shranjene naslove</string>
+ <string name="mozac_feature_prompts_collapse_address_content_description_2">Skrij shranjene naslove</string>
<!-- Text for the manage addresses button. -->
<string name="mozac_feature_prompts_manage_address">Upravljanje naslovov</string>
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/res/values-su/strings.xml b/mobile/android/android-components/components/feature/prompts/src/main/res/values-su/strings.xml
index 8069cf1b66..d0bf44fd5e 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/res/values-su/strings.xml
+++ b/mobile/android/android-components/components/feature/prompts/src/main/res/values-su/strings.xml
@@ -17,7 +17,9 @@
<!-- Text for password field in an authentication dialog. -->
<string name="mozac_feature_prompt_password_hint">Kecap sandi</string>
<!-- Negative confirmation that we should not save the new or updated login -->
- <string name="mozac_feature_prompt_dont_save">Ulah diteundeun</string>
+ <string name="mozac_feature_prompt_dont_save" moz:removedIn="125" tools:ignore="UnusedResources">Ulah diteundeun</string>
+ <!-- Negative confirmation that we should not save the new or updated login -->
+ <string name="mozac_feature_prompt_dont_save_2">Moal waka</string>
<!-- Negative confirmation that we should never save a login for this site -->
<string name="mozac_feature_prompt_never_save">Ulah diteundeun</string>
<!-- Negative confirmation that we should not save a credit card for this site -->
@@ -25,17 +27,27 @@
<!-- Positive confirmation that we should save the new or updated login -->
<string name="mozac_feature_prompt_save_confirmation">Teundeun</string>
<!-- Negative confirmation that we should not save the updated login -->
- <string name="mozac_feature_prompt_dont_update">Ulah ngapdét</string>
+ <string name="mozac_feature_prompt_dont_update" moz:removedIn="125" tools:ignore="UnusedResources">Ulah ngapdét</string>
+ <!-- Negative confirmation that we should not save the updated login -->
+ <string name="mozac_feature_prompt_dont_update_2">Moal waka</string>
<!-- Positive confirmation that we should save the updated login -->
<string name="mozac_feature_prompt_update_confirmation">Apdét</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_empty_password">Widang kecap sandi henteu kaci kosong</string>
+ <string name="mozac_feature_prompt_error_empty_password" moz:removedIn="125" tools:ignore="UnusedResources">Widang kecap sandi henteu kaci kosong</string>
+ <!-- Error text displayed underneath the password field when it is in an error case -->
+ <string name="mozac_feature_prompt_error_empty_password_2">Asupkeun sandi</string>
+ <!-- Error text displayed underneath the login field when it is in an error case -->
+ <string name="mozac_feature_prompt_error_unknown_cause" moz:removedIn="125" tools:ignore="UnusedResources">Teu bisa neundeun login</string>
<!-- Error text displayed underneath the password field when it is in an error case -->
- <string name="mozac_feature_prompt_error_unknown_cause">Teu bisa neundeun login</string>
+ <string name="mozac_feature_prompt_error_unknown_cause_2">Teu bisa nyimpen santi</string>
<!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new login. -->
- <string name="mozac_feature_prompt_login_save_headline">Teundeun ieu login?</string>
+ <string name="mozac_feature_prompt_login_save_headline" moz:removedIn="125" tools:ignore="UnusedResources">Teundeun ieu login?</string>
+ <!-- Prompt message displayed when app detects a user has entered a new username and password and user decides if app should save the new password. -->
+ <string name="mozac_feature_prompt_login_save_headline_2">Simpen sandi?</string>
<!-- Prompt message displayed when app detects a user has entered a new password for an existing login and user decides if app should update the login. -->
- <string name="mozac_feature_prompt_login_update_headline">Apdét ieu login?</string>
+ <string name="mozac_feature_prompt_login_update_headline" moz:removedIn="125" tools:ignore="UnusedResources">Apdét ieu login?</string>
+ <!-- Prompt message displayed when app detects a user has entered a new password for an existing login and user decides if app should update the password. -->
+ <string name="mozac_feature_prompt_login_update_headline_2">Anyarkeun sandi?</string>
<!-- Prompt message displayed when app detects a user has entered a username for an existing login without a username and user decides if app should update the login. -->
<string name="mozac_feature_prompt_login_add_username_headline">Tambahkeun sandiasma kana kecap sandi anu diteundeun?</string>
<!-- Text for a label for the field when prompt requesting a text is shown. -->
@@ -84,13 +96,22 @@
<!-- Title of the time picker dialog. -->
<string name="mozac_feature_prompts_set_time">Setél wanci</string>
<!-- Option in expanded select login prompt that links to login settings -->
- <string name="mozac_feature_prompts_manage_logins">Kokolakeun login</string>
+ <string name="mozac_feature_prompts_manage_logins" moz:removedIn="125" tools:ignore="UnusedResources">Kokolakeun login</string>
+ <!-- Option in expanded select password prompt that links to password settings -->
+ <string name="mozac_feature_prompts_manage_logins_2">Atur sandi</string>
<!-- Content description for expanding the saved logins options in the select login prompt -->
- <string name="mozac_feature_prompts_expand_logins_content_description">Legaan saran login</string>
+ <string name="mozac_feature_prompts_expand_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Legaan saran login</string>
+ <!-- Content description for expanding the saved passwords options in the select password prompt -->
+ <string name="mozac_feature_prompts_expand_logins_content_description_2">Legaan sandi anu disimpen</string>
<!-- Content description for collapsing the saved logins options in the select login prompt -->
- <string name="mozac_feature_prompts_collapse_logins_content_description">Leutikan saran login</string>
+ <string name="mozac_feature_prompts_collapse_logins_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Leutikan saran login</string>
+ <!-- Content description for collapsing the saved passwords options in the select password prompt -->
+ <string name="mozac_feature_prompts_collapse_logins_content_description_2">Heureutan sandi nu disimpen</string>
<!-- Header for the select login prompt to allow users to fill a form with a saved login -->
- <string name="mozac_feature_prompts_saved_logins">Saran login</string>
+ <string name="mozac_feature_prompts_saved_logins" moz:removedIn="125" tools:ignore="UnusedResources">Saran login</string>
+
+ <!-- Header for the select password prompt to allow users to fill a form with a saved password -->
+ <string name="mozac_feature_prompts_saved_logins_2">Sandi nu disimpen</string>
<!-- Content description for the suggest strong password prompt to allow users to fill a form with a suggested strong password -->
<string name="mozac_feature_prompts_suggest_strong_password_content_description">Usulkeun kecap sandi anu wedel</string>
@@ -109,27 +130,42 @@
<!-- Credit Card Autofill -->
<!-- Header for the select credit card prompt to allow users to fill a form with a saved credit card. -->
- <string name="mozac_feature_prompts_select_credit_card">Pilih kartu kiridit</string>
+ <string name="mozac_feature_prompts_select_credit_card" moz:removedIn="125" tools:ignore="UnusedResources">Pilih kartu kiridit</string>
+ <!-- Header for the select card prompt to allow users to fill a form with a saved card. -->
+ <string name="mozac_feature_prompts_select_credit_card_2">Paké kartu nu disimpen</string>
<!-- Content description for expanding the select credit card options in the select credit card prompt. -->
- <string name="mozac_feature_prompts_expand_credit_cards_content_description">Legaan kartu kiridit anu disarankeun</string>
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Legaan kartu kiridit anu disarankeun</string>
+ <!-- Content description for expanding the saved card options in the select card prompt. -->
+ <string name="mozac_feature_prompts_expand_credit_cards_content_description_2">Legaan kartu nu disimpen</string>
<!-- Content description for collapsing the select credit card options in the select credit prompt. -->
- <string name="mozac_feature_prompts_collapse_credit_cards_content_description">Tilep saran kartu kiridit</string>
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Tilep saran kartu kiridit</string>
+ <!-- Content description for collapsing the saved card options in the select prompt. -->
+ <string name="mozac_feature_prompts_collapse_credit_cards_content_description_2">Heureutan kartu nu disimpen</string>
<!-- Option in the expanded select credit card prompt that links to credit cards settings. -->
- <string name="mozac_feature_prompts_manage_credit_cards">Kokolakeun kartu kiridit</string>
+ <string name="mozac_feature_prompts_manage_credit_cards" moz:removedIn="125" tools:ignore="UnusedResources">Kokolakeun kartu kiridit</string>
+ <!-- Option in the expanded select card prompt that links to cards settings. -->
+ <string name="mozac_feature_prompts_manage_credit_cards_2">Atur kartu</string>
<!-- Text for the title of a save credit card dialog. -->
<string name="mozac_feature_prompts_save_credit_card_prompt_title">Teundeun ieu kartu sacara aman?</string>
<!-- Text for the title of an update credit card dialog. -->
<string name="mozac_feature_prompts_update_credit_card_prompt_title">Mutahirkeun titimangsa kadaluwarsa kartu?</string>
<!-- Subtitle text displayed under the title of the save credit card dialog. -->
- <string name="mozac_feature_prompts_save_credit_card_prompt_body">Nomer kartu bakal diénkrip. Kode kaamanan moal diteundeun.</string>
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body" moz:removedIn="125" tools:ignore="UnusedResources">Nomer kartu bakal diénkrip. Kode kaamanan moal diteundeun.</string>
+
+ <!-- Subtitle text displayed under the title of the saved card dialog. Parameter will be replaced by app name-->
+ <string name="mozac_feature_prompts_save_credit_card_prompt_body_2">%s énkripsi nomer kartu anjeun. Kode kaamanan anjeun moal disimpen.</string>
<!-- Address Autofill -->
<!-- Header for the select address prompt to allow users to fill a form with a saved address. -->
<string name="mozac_feature_prompts_select_address_2">Pilih alamat</string>
<!-- Content description for expanding the select addresses options in the select address prompt. -->
- <string name="mozac_feature_prompts_expand_address_content_description">Legaan saran alamat</string>
+ <string name="mozac_feature_prompts_expand_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Legaan saran alamat</string>
+ <!-- Content description for expanding the saved addresses options in the select address prompt. -->
+ <string name="mozac_feature_prompts_expand_address_content_description_2">Legaan alamat nu disimpen</string>
<!-- Content description for collapsing the select address options in the select address prompt. -->
- <string name="mozac_feature_prompts_collapse_address_content_description">Leutikan saran alamat</string>
+ <string name="mozac_feature_prompts_collapse_address_content_description" moz:removedIn="125" tools:ignore="UnusedResources">Leutikan saran alamat</string>
+ <!-- Content description for collapsing the saved address options in the select address prompt. -->
+ <string name="mozac_feature_prompts_collapse_address_content_description_2">Heureutan alamat nu disimpen</string>
<!-- Text for the manage addresses button. -->
<string name="mozac_feature_prompts_manage_address">Kokolakeun alamat</string>
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/res/values/quarantined_strings.xml b/mobile/android/android-components/components/feature/prompts/src/main/res/values/quarantined_strings.xml
index 5943e14165..1564be16e2 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/res/values/quarantined_strings.xml
+++ b/mobile/android/android-components/components/feature/prompts/src/main/res/values/quarantined_strings.xml
@@ -5,5 +5,5 @@
<!-- Strings in this file are not yet ready for localization. -->
<resources>
<!-- Text of the title of a dialog when a page is requesting to open a new window. -->
- <string name="mozac_feature_prompts_popup_dialog_title">Prevent this site from opening a pop-up window?</string>
+ <string name="mozac_feature_prompts_popup_dialog_title">Allow this site to open?</string>
</resources>
diff --git a/mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/PromptFeature.kt b/mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/PromptFeature.kt
index 481b0e5ce3..768fddddb9 100644
--- a/mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/PromptFeature.kt
+++ b/mobile/android/android-components/components/feature/prompts/src/main/java/mozilla/components/feature/prompts/PromptFeature.kt
@@ -17,6 +17,7 @@ import kotlinx.coroutines.flow.map
import mozilla.components.browser.state.action.ContentAction
import mozilla.components.browser.state.selector.findTabOrCustomTab
import mozilla.components.browser.state.selector.findTabOrCustomTabOrSelectedTab
+import mozilla.components.browser.state.selector.selectedTab
import mozilla.components.browser.state.state.SessionState
import mozilla.components.browser.state.store.BrowserStore
import mozilla.components.concept.engine.prompt.Choice
@@ -100,6 +101,7 @@ import mozilla.components.support.base.feature.PermissionsFeature
import mozilla.components.support.base.feature.UserInteractionHandler
import mozilla.components.support.base.log.logger.Logger
import mozilla.components.support.ktx.kotlin.ifNullOrEmpty
+import mozilla.components.support.ktx.kotlin.tryGetHostFromUrl
import mozilla.components.support.ktx.kotlinx.coroutines.flow.ifAnyChanged
import java.lang.ref.WeakReference
import java.security.InvalidParameterException
@@ -134,6 +136,8 @@ internal const val FRAGMENT_TAG = "mozac_feature_prompt_dialog"
* a dialog (fragment).
* @property shareDelegate Delegate used to display share sheet.
* @property exitFullscreenUsecase Usecase allowing to exit browser tabs' fullscreen mode.
+ * @property isLoginAutofillEnabled A callback invoked before an autofill prompt is triggered. If false,
+ * 'autofill login' prompts will not be shown.
* @property isSaveLoginEnabled A callback invoked when a login prompt is triggered. If false,
* 'save login' prompts will not be shown.
* @property isCreditCardAutofillEnabled A callback invoked when credit card fields are detected in the webpage.
@@ -171,6 +175,7 @@ class PromptFeature private constructor(
private val exitFullscreenUsecase: ExitFullScreenUseCase = SessionUseCases(store).exitFullscreen,
override val creditCardValidationDelegate: CreditCardValidationDelegate? = null,
override val loginValidationDelegate: LoginValidationDelegate? = null,
+ private val isLoginAutofillEnabled: () -> Boolean = { false },
private val isSaveLoginEnabled: () -> Boolean = { false },
private val isCreditCardAutofillEnabled: () -> Boolean = { false },
private val isAddressAutofillEnabled: () -> Boolean = { false },
@@ -219,6 +224,7 @@ class PromptFeature private constructor(
exitFullscreenUsecase: ExitFullScreenUseCase = SessionUseCases(store).exitFullscreen,
creditCardValidationDelegate: CreditCardValidationDelegate? = null,
loginValidationDelegate: LoginValidationDelegate? = null,
+ isLoginAutofillEnabled: () -> Boolean = { false },
isSaveLoginEnabled: () -> Boolean = { false },
isCreditCardAutofillEnabled: () -> Boolean = { false },
isAddressAutofillEnabled: () -> Boolean = { false },
@@ -243,6 +249,7 @@ class PromptFeature private constructor(
exitFullscreenUsecase = exitFullscreenUsecase,
creditCardValidationDelegate = creditCardValidationDelegate,
loginValidationDelegate = loginValidationDelegate,
+ isLoginAutofillEnabled = isLoginAutofillEnabled,
isSaveLoginEnabled = isSaveLoginEnabled,
isCreditCardAutofillEnabled = isCreditCardAutofillEnabled,
isAddressAutofillEnabled = isAddressAutofillEnabled,
@@ -267,6 +274,7 @@ class PromptFeature private constructor(
exitFullscreenUsecase: ExitFullScreenUseCase = SessionUseCases(store).exitFullscreen,
creditCardValidationDelegate: CreditCardValidationDelegate? = null,
loginValidationDelegate: LoginValidationDelegate? = null,
+ isLoginAutofillEnabled: () -> Boolean = { false },
isSaveLoginEnabled: () -> Boolean = { false },
isCreditCardAutofillEnabled: () -> Boolean = { false },
isAddressAutofillEnabled: () -> Boolean = { false },
@@ -290,6 +298,7 @@ class PromptFeature private constructor(
exitFullscreenUsecase = exitFullscreenUsecase,
creditCardValidationDelegate = creditCardValidationDelegate,
loginValidationDelegate = loginValidationDelegate,
+ isLoginAutofillEnabled = isLoginAutofillEnabled,
isSaveLoginEnabled = isSaveLoginEnabled,
isCreditCardAutofillEnabled = isCreditCardAutofillEnabled,
isAddressAutofillEnabled = isAddressAutofillEnabled,
@@ -436,12 +445,12 @@ class PromptFeature private constructor(
}
}
// Dismiss all prompts when page URL or session id changes. See Fenix#5326
dismissPromptScope = store.flowScoped { flow ->
flow.ifAnyChanged { state ->
arrayOf(
state.selectedTabId,
- state.findTabOrCustomTabOrSelectedTab(customTabId)?.content?.url,
+ state.findTabOrCustomTabOrSelectedTab(customTabId)?.content?.url?.tryGetHostFromUrl(),
)
}.collect {
dismissSelectPrompts()
@@ -559,17 +568,18 @@ class PromptFeature private constructor(
}
is SelectLoginPrompt -> {
- if (promptRequest.logins.isEmpty()) {
- if (isSuggestStrongPasswordEnabled) {
- val currentUrl =
- store.state.findTabOrCustomTabOrSelectedTab(customTabId)?.content?.url
- if (currentUrl != null) {
- strongPasswordPromptViewListener?.handleSuggestStrongPasswordRequest(
- promptRequest,
- currentUrl,
- onSaveLoginWithStrongPassword,
- )
- }
+ if (!isLoginAutofillEnabled()) {
+ return
+ }
+ if (promptRequest.generatedPassword != null && isSuggestStrongPasswordEnabled) {
+ val currentUrl =
+ store.state.findTabOrCustomTabOrSelectedTab(customTabId)?.content?.url
+ if (currentUrl != null) {
+ strongPasswordPromptViewListener?.handleSuggestStrongPasswordRequest(
+ promptRequest,
+ currentUrl,
+ onSaveLoginWithStrongPassword,
+ )
}
} else {
loginPicker?.handleSelectLoginRequest(promptRequest)
@@ -872,6 +882,7 @@ class PromptFeature private constructor(
inputLabel,
inputValue,
promptAbuserDetector.areDialogsBeingAbused(),
+ store.state.selectedTab?.content?.private == true,
)
}
}
@@ -436,12 +445,12 @@ class PromptFeature private constructor(
}
}
- // Dismiss all prompts when page URL or session id changes. See Fenix#5326
+ // Dismiss all prompts when page host or session id changes. See Fenix#5326
dismissPromptScope = store.flowScoped { flow ->
flow.ifAnyChanged { state ->